#

    	ingredient scan

    		description:
    			This is for the "Essential Nutrients", "Cautionary Nutrients",
    			etc. panels.

    			These are procedures that are used by both the
    			ETL of the USDA foods and NIH supplements.

    		databases:
    			essentials

    			cautionary

    		status:
    			python3 insurance.py "shows/ingredient_scan/**/status_*.py"

    		important:
    			#
    			#	This builds the proceeds of the scan
    			#
    			land.build
    				grove.nurture

    		(with exceptions) breakdown:
    			This might need to include "cautionary nutrients" also.

    				Therefore, "FDA ingredients chart"

    				Therefore, "essential (and cautionary) nutrients"
    				Therefore, "essential (to include) nutrients"
    				Therefore, "relevant nutrients"

    		relevant:
    			https://fdc.nal.usda.gov/portal-data/external/fullNutrientList

    			This is based on the essential nutrients defined by the FDA:
    				https://www.fda.gov/food/nutrition-facts-label/daily-value-nutrition-and-supplement-facts-labels